This is the source code for ["An MCMC Based Course to Teaching Assistant Allocation", S. Kumar, S. Moothedath, P. Chaporkar, M. Belur, Proceedings of the Fifth International Conference on Network, Communication and Computing (2016). ACM.](https://doi.org/10.1145/3033288.3033297)
    
    PS: The code is not optimized for performance!

Also I am working towards packaging this code. Updates soon!